@@ -1,4 +1,4 @@
-#' calculate keyness statistics
+#' Calculate keyness statistics
 #' 
 #' Calculate "keyness", a score for features that occur differentially across 
 #' different categories.  Here, the categories are defined by reference to a
@@ -42,6 +42,8 @@
 #'   likelihood ratio \eqn{G2} statistic; for \code{"pmi"} this is the pointwise
 #'   mutual information statistics.
 #' @export
+#' @return \code{textstat_keyness} returns a data.frame of features and
+#'   their keyness scores and frequency counts.
 #' @keywords textstat
 #' @importFrom stats chisq.test
 #' @examples
@@ -61,15 +63,26 @@
 #' head(textstat_keyness(pwdfm, target = "2017-Trump"), 10)
 #' # using the likelihood ratio method
 #' head(textstat_keyness(dfm_smooth(pwdfm), measure = "lr", target = "2017-Trump"), 10)
-textstat_keyness <- function(x, target = 1L, measure = c("chi2", "exact", "lr", "pmi"), sort = TRUE, 
+textstat_keyness <- function(x, target = 1L, 
+                             measure = c("chi2", "exact", "lr", "pmi"), 
+                             sort = TRUE, 
                              correction = c("default", "yates", "williams", "none")) {
     UseMethod("textstat_keyness")
 }
 
-#' @noRd
 #' @export
-textstat_keyness.dfm <- function(x, target = 1L, measure = c("chi2", "exact", "lr", "pmi"), 
-                                 sort = TRUE, correction = c("default", "yates", "williams", "none")) {
+textstat_keyness.default <- function(x, target = 1L, 
+                                     measure = c("chi2", "exact", "lr", "pmi"), 
+                                     sort = TRUE, 
+                                     correction = c("default", "yates", "williams", "none")) {
+    stop(friendly_class_undefined_message(class(x), "textstat_keyness"))
+}
+
+#' @export
+textstat_keyness.dfm <- function(x, target = 1L, 
+                                 measure = c("chi2", "exact", "lr", "pmi"), 
+                                 sort = TRUE, 
+                                 correction = c("default", "yates", "williams", "none")) {
     
     
     x <- as.dfm(x)
@@ -96,35 +109,32 @@ textstat_keyness.dfm <- function(x, target = 1L, measure = c("chi2", "exact", "l
     x <- x[order(docnames(x)), ]
     
     if (measure == "chi2") {
-        keywords <- keyness_chi2_dt(x, correction)
+        result <- keyness_chi2_dt(x, correction)
     } else if (measure == "lr") {
-        keywords <- keyness_lr(x, correction)
+        result <- keyness_lr(x, correction)
     } else if (measure == "exact") {
         if (!correction %in% c("default", "none"))
             warning("correction is always none for measure exact")
-        keywords <- keyness_exact(x)
+        result <- keyness_exact(x)
     } else if (measure == "pmi") {
         if (!correction %in% c("default", "none"))
             warning("correction is always none for measure pmi")
-        keywords <- keyness_pmi(x)
+        result <- keyness_pmi(x)
     } else {
         stop(measure, " not yet implemented for textstat_keyness")
     }
     
     if (sort)
-        keywords <- keywords[order(keywords[, 1], decreasing = TRUE), ]
+        result <- result[order(result[, 2], decreasing = TRUE), ]
     
-    names(keywords)[which(names(keywords) == "target")] <- "n_target"
-    names(keywords)[which(names(keywords) == "reference")] <- "n_reference"
-    
-    doc_names <- grouping[order(grouping)]
-    attr(keywords, "documents") <- names(doc_names)
-    
-    return(keywords)
+    attr(result, "documents") <- names(grouping[order(grouping)])
+    class(result) <- c('keyness', 'textstat', 'data.frame')
+    rownames(result) <- as.character(seq_len(nrow(result)))
+    return(result)
 }
 
 
-#' compute keyness (internal functions)
+#' Compute keyness (internal functions)
 #' 
 #' Internal function used in textstat_keyness.  Computes \eqn{chi^2} with Yates'
 #' continuity correction for 2x2 tables.
@@ -178,11 +188,12 @@ keyness_chi2_dt <- function(x, correction = c("default", "yates", "williams", "n
     # compute p-values
     dt[, p := 1 - stats::pchisq(abs(chi2), 1)]
     
-    result <- as.data.frame(dt[, list(chi2, p)])
-    rownames(result) <- dt$feature
-    result$target = as.vector(x[1,])
-    result$reference = as.vector(x[2,])
-    return(result)
+    data.frame(feature = dt$feature, 
+               chi2 = dt[, chi2],
+               p = dt[, p],
+               n_target = as.vector(x[1,]),
+               n_reference = as.vector(x[2,]),
+               stringsAsFactors = FALSE)
 }
 
 #' @rdname keyness
@@ -193,28 +204,36 @@ keyness_chi2_dt <- function(x, correction = c("default", "yates", "williams", "n
 #' @examples 
 #' quanteda:::keyness_chi2_stats(mydfm)
 keyness_chi2_stats <- function(x) {
-    keyness <- function(t, f, sum_t, sum_f) {
-        # @param t (scalar) frequency of target 
-        # @param f (scalar) frequency of reference
-        # @param sum_t total of all target words
-        # @param sum_f total of all reference words
-        tb <- as.table(rbind(c(t, f), c(sum_t - t, sum_f - f)))
-        suppressWarnings(chi <- stats::chisq.test(tb))
-        t_exp <- chi$expected[1,1]
-        list(chi2 = unname(chi$statistic) * ifelse(t > t_exp, 1, -1),
-             p = unname(chi$p.value))
-    }
+    
     sums <- rowSums(x)
     result <- as.data.frame(
         do.call(rbind, apply(x, 2, function(y) keyness(as.numeric(y[1]), 
-                                                       as.numeric(y[2]), 
-                                                       sums[1], sums[2])))
+                                                              as.numeric(y[2]), 
+                                                              sums[1], sums[2])))
     )
-    result$target = as.vector(x[1,])
-    result$reference = as.vector(x[2,])
-    return(result)
+
+    data.frame(feature = colnames(x), 
+               chi2 = result$chi2,
+               p = result$p,
+               n_target = as.vector(x[1,]),
+               n_reference = as.vector(x[2,]),
+               stringsAsFactors = FALSE)
 }
 
+#' @rdname keyness
+#' @param t (scalar) frequency of target 
+#' @param f (scalar) frequency of reference
+#' @param sum_t total of all target words
+#' @param sum_f total of all reference words
+#' @keywords internal
+keyness <- function(t, f, sum_t, sum_f) {
+
+    tb <- as.table(rbind(c(t, f), c(sum_t - t, sum_f - f)))
+    suppressWarnings(chi <- stats::chisq.test(tb))
+    t_exp <- chi$expected[1,1]
+    list(chi2 = unname(chi$statistic) * ifelse(t > t_exp, 1, -1),
+         p = unname(chi$p.value))
+}
 
 #' @rdname keyness
 #' @details 
@@ -228,13 +247,19 @@ keyness_exact <- function(x) {
     result <- as.data.frame(
         do.call(rbind, 
                 apply(x, 2, function(y) { 
-                    et <- stats::fisher.test(matrix(c(as.numeric(y), as.numeric(sums - y)), nrow = 2))
+                    et <- stats::fisher.test(matrix(c(as.numeric(y), 
+                                                      as.numeric(sums - y)), 
+                                                    nrow = 2))
                     data.frame(or = as.numeric(et$estimate), p = et$p.value)
                 }))
     )
-    result$target = as.vector(x[1,])
-    result$reference = as.vector(x[2,])
-    return(result)
+
+    data.frame(feature = colnames(x), 
+               or = result$or,
+               p = result$p,
+               n_target = as.vector(x[1,]),
+               n_reference = as.vector(x[2,]),
+               stringsAsFactors = FALSE)
 }
 
 
@@ -286,22 +311,25 @@ keyness_lr <- function(x, correction = c("default", "yates", "williams", "none")
     if (correction == "williams"){
         # William's correction cannot be used if there are any zeros in the table
         # \url{http://influentialpoints.com/Training/g-likelihood_ratio_test.htm}
-        dt[, q := ifelse(a * b * c * d == 0, 1, 1 + (N/(a + b) + N/(c + d) - 1) * (N/(a + c) + N/(b + d) - 1) / (6 * N) )]
+        dt[, q := ifelse(a * b * c * d == 0, 
+                         1, 
+                         1 + (N/(a + b) + N/(c + d) - 1) * (N/(a + c) + N/(b + d) - 1) / (6 * N) )]
         dt[, G2 := G2 / q]
     }
     
     # compute p-values
     dt[, p := 1 - stats::pchisq(abs(G2), 1)]
     
-    result <- as.data.frame(dt[, list(G2, p)])
-    rownames(result) <- dt$feature
-    result$target = as.vector(x[1,])
-    result$reference = as.vector(x[2,])
-    return(result)
+    data.frame(feature = dt$feature, 
+               G2 = dt[, G2],
+               p = dt[, p],
+               n_target = as.vector(x[1,]),
+               n_reference = as.vector(x[2,]),
+               stringsAsFactors = FALSE)
 }
 
 #' @rdname keyness
-#' @details \code{keyness_pmi} computes the Pointwise Mutual Information statistic
+#' @details \code{keyness_pmi} computes the Pointwise Mutual Information stat
 #'   using vectorized computation
 #' @examples
 #' quanteda:::keyness_pmi(mydfm)
@@ -322,15 +350,13 @@ keyness_pmi <- function(x) {
     #normalized pmi
     #dt[, pmi :=   log(a  / E11) * ifelse(a > E11, 1, -1)/(-log(a/N)) ]
     
-    
     # compute p-values
     dt[, p := 1 - stats::pchisq(abs(pmi), 1)]
     
-    result <- as.data.frame(dt[, list(pmi, p)])
-    rownames(result) <- dt$feature
-    result$target = as.vector(x[1,])
-    result$reference = as.vector(x[2,])
-    return(result)
+    data.frame(feature = dt$feature, 
+               pmi = dt[, pmi],
+               p = dt[, p],
+               n_target = as.vector(x[1,]),
+               n_reference = as.vector(x[2,]),
+               stringsAsFactors = FALSE)
 }
-
-
