@@ -1,4 +1,4 @@
-#' convert token sequences into compound tokens
+#' Convert token sequences into compound tokens
 #' 
 #' Replace multi-token sequences with a multi-word, or "compound" token.  The
 #' resulting compound tokens will represent a phrase or multi-word expression, 
@@ -55,9 +55,13 @@ tokens_compound <- function(x, pattern,
     UseMethod("tokens_compound")
 }
 
+#' @export
+tokens_compound.default <- function(x, pattern,
+                                   concatenator = "_", valuetype = c("glob", "regex", "fixed"),
+                                   case_insensitive = TRUE, join = TRUE) {
+    stop(friendly_class_undefined_message(class(x), "tokens_compound"))
+}
 
-#' @rdname tokens_compound
-#' @noRd
 #' @importFrom RcppParallel RcppParallelLibs
 #' @export
 tokens_compound.tokens <- function(x, pattern,
@@ -75,6 +79,3 @@ tokens_compound.tokens <- function(x, pattern,
     attr(x, "concatenator") <- concatenator
     return(x)
 }
-
-
-
