@@ -1,4 +1,4 @@
-#' create ngrams and skipgrams from tokens
+#' Create ngrams and skipgrams from tokens
 #' 
 #' Create a set of ngrams (tokens in sequence) from already tokenized text
 #' objects, with an optional skip argument to form skipgrams. Both the ngram
@@ -41,10 +41,15 @@ tokens_ngrams <- function(x, n = 2L, skip = 0L, concatenator = "_") {
     UseMethod("tokens_ngrams")
 }
 
-#' @rdname ngrams
-#' @importFrom stats complete.cases
-#' @noRd
 #' @export
+tokens_ngrams.default <- function(x, n = 2L, skip = 0L, concatenator = "_") {
+    stop(friendly_class_undefined_message(class(x), "tokens_ngrams"))
+}
+
+## this function is not exported because it should not exist - it violates
+## the grammatrical rules of quanteda (inputs character, outputs tokens),
+## but starts with "tokens_"
+#' @importFrom stats complete.cases
 tokens_ngrams.character <- function(x, n = 2L, skip = 0L, concatenator = "_") {
     # trap condition where a "text" is a single NA
     if (is.na(x[1]) && length(x)==1) return(NULL)
@@ -74,7 +79,11 @@ char_ngrams <- function(x, n = 2L, skip = 0L, concatenator = "_") {
     UseMethod("char_ngrams")
 }
 
-#' @noRd
+#' @export
+char_ngrams.default <- function(x, n = 2L, skip = 0L, concatenator = "_") {
+    stop(friendly_class_undefined_message(class(x), "char_ngrams"))
+}
+
 #' @export
 char_ngrams.character <- function(x, n = 2L, skip = 0L, concatenator = "_") {
     as.character(tokens_ngrams(x, n, skip, concatenator))
@@ -130,8 +139,12 @@ tokens_skipgrams <- function(x, n, skip, concatenator="_") {
     UseMethod("tokens_skipgrams")
 }
 
-#' @noRd
 #' @export
-tokens_skipgrams <- function(x, n, skip, concatenator="_") {
+tokens_skipgrams.default <- function(x, n, skip, concatenator="_") {
+    stop(friendly_class_undefined_message(class(x), "tokens_skipgrams"))
+}
+
+#' @export
+tokens_skipgrams.tokens <- function(x, n, skip, concatenator="_") {
     tokens_ngrams(x, n = n, skip = skip, concatenator = concatenator)
 }
