@@ -191,7 +191,7 @@ test_that("test textstat_dist method = \"hamming\" against e1071::hamming.distan
     hammingQuanteda <- hammingQuanteda[-which(names(hammingQuanteda) == "1981-Reagan")]
     
     if (requireNamespace("e1071", quietly = TRUE)) {
-        hammingE1071 <- sort(e1071::hamming.distance(as.matrix(tf(presDfm, "boolean")))[, "1981-Reagan"], decreasing = FALSE)
+        hammingE1071 <- sort(e1071::hamming.distance(as.matrix(dfm_weight(presDfm, "boolean")))[, "1981-Reagan"], decreasing = FALSE)
         if("1981-Reagan" %in% names(hammingE1071)) hammingE1071 <- hammingE1071[-which(names(hammingE1071) == "1981-Reagan")]
     } else {
         hammingE1071 <- c(712, 723, 746, 769, 774, 781, 784, 812, 857)
@@ -208,7 +208,7 @@ test_that("test textstat_dist method = \"hamming\" against e1071::hamming.distan
     hammingQuanteda <- hammingQuanteda[order(names(hammingQuanteda))]
     hammingQuanteda <- hammingQuanteda[-which(names(hammingQuanteda) == "soviet")]
     
-    presM <- t(as.matrix(tf(presDfm, "boolean")))
+    presM <- t(as.matrix(dfm_weight(presDfm, "boolean")))
     hammingE1071 <- e1071::hamming.distance(presM)[, "soviet"]
     hammingE1071 <- hammingE1071[order(names(hammingE1071))]
     if("soviet" %in% names(hammingE1071)) hammingE1071 <- hammingE1071[-which(names(hammingE1071) == "soviet")]
@@ -253,14 +253,18 @@ test_that("textstat_dist stops as expected for methods not supported",{
     presDfm <- dfm(corpus_subset(data_corpus_inaugural, Year > 1980), remove = stopwords("english"),
                    stem = TRUE, verbose = FALSE)
     expect_error(textstat_dist(presDfm, method = "Yule"), 
-                 "Yule is not implemented; consider trying proxy::dist\\(\\)")
+                 "yule is not implemented; consider trying proxy::dist\\(\\)")
 })
 
 test_that("textstat_dist stops as expected for wrong selections",{
     presDfm <- dfm(corpus_subset(data_corpus_inaugural, Year > 1980), remove = stopwords("english"),
                    stem = TRUE, verbose = FALSE)
     expect_error(textstat_dist(presDfm, 5), 
-                 "'selection' should be character or character vector of document names or feature labels.")
+                 "The vector/matrix specified by 'selection' must be conform to the object x in columns")
+    expect_error(textstat_dist(presDfm, 5, margin = "features"), 
+                 "The vector/matrix specified by 'selection' must be conform to the object x in rows")
+    
+    
     
     expect_error(textstat_dist(presDfm, margin = "documents", "2009-Obamaa"), 
                  "The documents specified by 'selection' do not exist.")
@@ -279,3 +283,23 @@ test_that("as.dist on a dist returns a dist", {
     expect_equivalent(textstat_dist(presDfm, upper = TRUE, diag = TRUE), 
                       as.dist(distmat, upper = TRUE, diag = TRUE)) 
 })
+
+test_that("selection offers option to enable an alien vector/matrix", {
+    presDfm <- dfm(corpus_subset(data_corpus_inaugural, Year > 1990), remove = stopwords("english"),
+                   stem = TRUE, verbose = FALSE)
+    
+    expect_error(textstat_dist(presDfm, c(1,2,3,4,5,6,7), margin = "features"), NA)
+    
+})
+
+
+test_that("selection works with dfm with padding", {
+    
+    toks <- tokens(c(doc1 = 'a b c d e', doc2 = 'b c f e'), remove_punct = TRUE)
+    toks <- tokens_remove(toks, 'b', padding = TRUE)
+    mt <- dfm(toks)
+    expect_silent(textstat_dist(mt, selection = c('c'), margin = 'features'))
+    expect_silent(textstat_dist(mt, selection = c(''), margin = 'features'))
+    expect_silent(textstat_dist(mt, selection = c('doc2'), margin = 'documents'))
+    
+})
